@@ -119,11 +119,13 @@ def de_to_one_hot(labels):
 # 可以支持三维转二维的或者二维转一维的
 def de_to_one_hot_auto(labels):
     if len(labels.shape) == 2:
-        de_to_one_hot(labels)
+        return de_to_one_hot(labels)
     elif len(labels.shape) == 3:
-        de_to_one_hot_3dim(labels)
+        return de_to_one_hot_3dim(labels)
     else:
         print("目前仅支持三维转二维或者二维转一维!")
+        exit()
+
 
 
 # 做随机分割样本，all_num为样本总数，train_ratio为要分出训练集的比例，例如（124000,7,2,1）
